@@ -39,7 +39,7 @@
 **
 ** The code in this file abstracts the web-request so that downstream
 ** modules that generate the body of the reply (based on the requested page)
-** do not need to know if the request is coming from CGI, direct HTTP, 
+** do not need to know if the request is coming from CGI, direct HTTP,
 ** SCGI, or some other means.
 **
 ** This module gathers information about web page request into a key/value
@@ -483,7 +483,7 @@ void cgi_reply(void){
 
   if( g.fullHttpReply ){
     if( rangeEnd>0
-     && iReplyStatus==200 
+     && iReplyStatus==200
      && fossil_strcmp(P("REQUEST_METHOD"),"GET")==0
     ){
       iReplyStatus = 206;
@@ -564,7 +564,7 @@ void cgi_reply(void){
     if( iReplyStatus==206 ){
       blob_appendf(&hdr, "Content-Range: bytes %d-%d/%d\r\n",
               rangeStart, rangeEnd-1, total_size);
-      total_size = rangeEnd - rangeStart; 
+      total_size = rangeEnd - rangeStart;
     }
     blob_appendf(&hdr, "Content-Length: %d\r\n", total_size);
   }else{
@@ -1240,7 +1240,7 @@ void cgi_trace(const char *z){
 }
 
 /* Forward declaration */
-static NORETURN void malformed_request(const char *zMsg);
+static NORETURN void malformed_request(const char *zMsg, ...);
 
 /*
 ** Checks the QUERY_STRING environment variable, sets it up
@@ -1258,7 +1258,7 @@ int cgi_setup_query_string(void){
     add_param_list(z, '&');
     z = (char*)P("skin");
     if( z ){
-      char *zErr = skin_use_alternative(z, 2);
+      char *zErr = skin_use_alternative(z, 2, SKIN_FROM_QPARAM);
       ++rc;
       if( !zErr && P("once")==0 ){
         cookie_write_parameter("skin","skin",z);
@@ -1313,7 +1313,7 @@ int cgi_setup_query_string(void){
 **      |       HTTP_HOST      |        PATH_INFO     QUERY_STRING
 **      |                      |
 **    REQUEST_SCHEMA         SCRIPT_NAME
-**               
+**
 */
 void cgi_init(void){
   char *z;
@@ -1323,6 +1323,7 @@ void cgi_init(void){
   const char *zRequestUri = cgi_parameter("REQUEST_URI",0);
   const char *zScriptName = cgi_parameter("SCRIPT_NAME",0);
   const char *zPathInfo = cgi_parameter("PATH_INFO",0);
+  const char *zContentLength = 0;
 #ifdef _WIN32
   const char *zServerSoftware = cgi_parameter("SERVER_SOFTWARE",0);
 #endif
@@ -1350,7 +1351,7 @@ void cgi_init(void){
 #ifdef _WIN32
   /* The Microsoft IIS web server does not define REQUEST_URI, instead it uses
   ** PATH_INFO for virtually the same purpose.  Define REQUEST_URI the same as
-  ** PATH_INFO and redefine PATH_INFO with SCRIPT_NAME removed from the 
+  ** PATH_INFO and redefine PATH_INFO with SCRIPT_NAME removed from the
   ** beginning. */
   if( zServerSoftware && strstr(zServerSoftware, "Microsoft-IIS") ){
     int i, j;
@@ -1409,7 +1410,7 @@ void cgi_init(void){
     add_param_list(z, ';');
     z = (char*)cookie_value("skin",0);
     if(z){
-      skin_use_alternative(z, 2);
+      skin_use_alternative(z, 2, SKIN_FROM_COOKIE);
     }
   }
 
@@ -1420,7 +1421,15 @@ void cgi_init(void){
     g.zIpAddr = fossil_strdup(z);
   }
 
-  len = atoi(PD("CONTENT_LENGTH", "0"));
+  zContentLength = P("CONTENT_LENGTH");
+  if( zContentLength==0 ){
+    len = 0;
+    if( sqlite3_stricmp(PD("REQUEST_METHOD",""),"POST")==0 ){
+      malformed_request("missing CONTENT_LENGTH on a POST method");
+    }
+  }else{
+    len = atoi(zContentLength);
+  }
   zType = P("CONTENT_TYPE");
   zSemi = zType ? strchr(zType, ';') : 0;
   if( zSemi ){
@@ -1769,6 +1778,7 @@ void cgi_load_environment(void){
     "FOSSIL_FORCE_TICKET_MODERATION", "FOSSIL_FORCE_WIKI_MODERATION",
     "FOSSIL_TCL_PATH", "TH1_DELETE_INTERP", "TH1_ENABLE_DOCS",
     "TH1_ENABLE_HOOKS", "TH1_ENABLE_TCL", "REMOTE_HOST",
+    "CONTENT_TYPE", "CONTENT_LENGTH",
   };
   int i;
   for(i=0; i<count(azCgiVars); i++) (void)P(azCgiVars[i]);
@@ -1813,7 +1823,7 @@ void cgi_print_all(int showAll, unsigned int eDest, FILE *out){
         break;
       }
       case 3: {
-        if( strlen(zValue)>100 ){
+        if( zValue!=0 && strlen(zValue)>100 ){
           fprintf(out,"%s = %.100s...\n", zName, zValue);
         }else{
           fprintf(out,"%s = %s\n", zName, zValue);
@@ -1913,11 +1923,22 @@ void cgi_vprintf(const char *zFormat, va_list ap){
 /*
 ** Send a reply indicating that the HTTP request was malformed
 */
-static NORETURN void malformed_request(const char *zMsg){
-  cgi_set_status(501, "Not Implemented");
-  cgi_printf(
-    "<html><body><p>Bad Request: %s</p></body></html>\n", zMsg
-  );
+static NORETURN void malformed_request(const char *zMsg, ...){
+  va_list ap;
+  char *z;
+  va_start(ap, zMsg);
+  z = vmprintf(zMsg, ap);
+  va_end(ap);
+  cgi_set_status(400, "Bad Request");
+  zContentType = "text/plain";
+  if( g.zReqType==0 ) g.zReqType = "WWW";
+  if( g.zReqType[0]=='C' && PD("SERVER_SOFTWARE",0)!=0 ){
+    const char *zServer = PD("SERVER_SOFTWARE","");
+    cgi_printf("Bad CGI Request from \"%s\": %s\n",zServer,z);
+  }else{
+    cgi_printf("Bad %s Request: %s\n", g.zReqType, z);
+  }
+  fossil_free(z);
   cgi_reply();
   fossil_exit(0);
 }
@@ -2034,8 +2055,9 @@ void cgi_handle_http_request(const char *zIpAddr){
   const char *zScheme = "http";
   char zLine[2000];     /* A single line of input. */
   g.fullHttpReply = 1;
+  g.zReqType = "HTTP";
   if( cgi_fgets(zLine, sizeof(zLine))==0 ){
-    malformed_request("missing HTTP header");
+    malformed_request("missing header");
   }
   blob_append(&g.httpHeader, zLine, -1);
   cgi_trace(zLine);
@@ -2047,13 +2069,14 @@ void cgi_handle_http_request(const char *zIpAddr){
    && fossil_strcmp(zToken,"POST")!=0
    && fossil_strcmp(zToken,"HEAD")!=0
   ){
-    malformed_request("unsupported HTTP method");
+    malformed_request("unsupported HTTP method: \"%s\" - Fossil only supports"
+                      "GET, POST, and HEAD", zToken);
   }
   cgi_setenv("GATEWAY_INTERFACE","CGI/1.0");
   cgi_setenv("REQUEST_METHOD",zToken);
   zToken = extract_token(z, &z);
   if( zToken==0 ){
-    malformed_request("malformed URL in HTTP header");
+    malformed_request("malformed URI in the HTTP header");
   }
   cgi_setenv("REQUEST_URI", zToken);
   cgi_setenv("SCRIPT_NAME", "");
@@ -2165,6 +2188,7 @@ void cgi_handle_ssh_http_request(const char *zIpAddr){
   }else{
     fossil_fatal("missing SSH IP address");
   }
+  g.zReqType = "HTTP";
   if( fgets(zLine, sizeof(zLine),g.httpIn)==0 ){
     malformed_request("missing HTTP header");
   }
@@ -2776,10 +2800,13 @@ int cgi_from_mobile(void){
 void cgi_check_for_malice(void){
   struct QParam * pParam;
   int i;
-  for(i = 0; i < nUsedQP; ++i){
+  for(i=0; i<nUsedQP; ++i){
     pParam = &aParamQP[i];
-    if(0 == pParam->isFetched
-       && fossil_islower(pParam->zName[0])){
+    if( 0==pParam->isFetched
+     && pParam->zValue!=0
+     && pParam->zName!=0
+     && fossil_islower(pParam->zName[0])
+    ){
       cgi_value_spider_check(pParam->zValue, pParam->zName);
     }
   }
