@@ -578,6 +578,7 @@ void leaves_page(void){
     style_submenu_element("Open", "%s", url_render(&url, 0, 0, 0, 0));
   }
   url_reset(&url);
+  cgi_check_for_malice();
   style_set_current_feature("leaves");
   style_header("Leaves");
   login_anonymous_available();
@@ -629,7 +630,7 @@ void leaves_page(void){
   if( fUBg ) tmFlags |= TIMELINE_UCOLOR;
   www_print_timeline(&q, tmFlags, 0, 0, 0, 0, 0, 0);
   db_finalize(&q);
-  @ <br />
+  @ <br>
   style_finish_page();
 }
 
