@@ -56,7 +56,7 @@
 */
 static void login_create_csrf_secret(const char *zSeed){
   unsigned char zResult[20];
-  int i;
+  unsigned int i;
 
   sha1sum_binary(zSeed, zResult);
   for(i=0; i<sizeof(g.zCsrfToken)-1; i++){
@@ -256,7 +256,7 @@ int login_search_uid(const char **pzUsername, const char *zPasswd){
       }
     }
     db_finalize(&q);
-  }    
+  }
   free(zSha1Pw);
   return uid;
 }
@@ -396,46 +396,29 @@ void login_clear_login_data(){
   }
 }
 
-/*
-** Return true if the prefix of zStr matches zPattern.  Return false if
-** they are different.
-**
-** A lowercase character in zPattern will match either upper or lower
-** case in zStr.  But an uppercase in zPattern will only match an
-** uppercase in zStr.
-*/
-static int prefix_match(const char *zPattern, const char *zStr){
-  int i;
-  char c;
-  for(i=0; (c = zPattern[i])!=0; i++){
-    if( zStr[i]!=c && fossil_tolower(zStr[i])!=c ) return 0;
-  }
-  return 1;
-}
-
 /*
 ** Look at the HTTP_USER_AGENT parameter and try to determine if the user agent
 ** is a manually operated browser or a bot.  When in doubt, assume a bot.
 ** Return true if we believe the agent is a real person.
 */
 static int isHuman(const char *zAgent){
-  int i;
   if( zAgent==0 ) return 0;  /* If no UserAgent, then probably a bot */
-  for(i=0; zAgent[i]; i++){
-    if( prefix_match("bot", zAgent+i) ) return 0;
-    if( prefix_match("spider", zAgent+i) ) return 0;
-    if( prefix_match("crawl", zAgent+i) ) return 0;
-    /* If a URI appears in the User-Agent, it is probably a bot */
-    if( strncmp("http", zAgent+i,4)==0 ) return 0;
-  }
+  if( strstr(zAgent, "bot")!=0 ) return 0;
+  if( strstr(zAgent, "spider")!=0 ) return 0;
+  if( strstr(zAgent, "crawl")!=0 ) return 0;
+  /* If a URI appears in the User-Agent, it is probably a bot */
+  if( strstr(zAgent, "http")!=0 ) return 0;
   if( strncmp(zAgent, "Mozilla/", 8)==0 ){
     if( atoi(&zAgent[8])<4 ) return 0;  /* Many bots advertise as Mozilla/3 */
 
+    /* Google AI Robot, maybe? */
+    if( strstr(zAgent, "GoogleOther)")!=0 ) return 0;
+
     /* 2016-05-30:  A pernicious spider that likes to walk Fossil timelines has
     ** been detected on the SQLite website.  The spider changes its user-agent
     ** string frequently, but it always seems to include the following text:
     */
-    if( sqlite3_strglob("*Safari/537.36Mozilla/5.0*", zAgent)==0 ) return 0;
+    if( strstr(zAgent, "Safari/537.36Mozilla/5.0")!=0 ) return 0;
 
     if( sqlite3_strglob("*Firefox/[1-9]*", zAgent)==0 ) return 1;
     if( sqlite3_strglob("*Chrome/[1-9]*", zAgent)==0 ) return 1;
@@ -777,7 +760,7 @@ void login_page(void){
     if( P("HTTPS")==0 ){
       @ <tr><td class="form_label">Warning:</td>
       @ <td><span class='securityWarning'>
-      @ Login information, including the password, 
+      @ Login information, including the password,
       @ will be sent in the clear over an unencrypted connection.
       if( !g.sslNotAvailable ){
         @ Consider logging in at
@@ -826,7 +809,7 @@ void login_page(void){
       const char *zDecoded = captcha_decode(uSeed);
       int bAutoCaptcha = db_get_boolean("auto-captcha", 0);
       char *zCaptcha = captcha_render(zDecoded);
-  
+
       @ <p><input type="hidden" name="cs" value="%u(uSeed)">
       @ Visitors may enter <b>anonymous</b> as the user-ID with
       @ the 8-character hexadecimal password shown below:</p>
@@ -855,6 +838,9 @@ void login_page(void){
       @ <a href="%R/timeline?ss=v&y=f&vfx&u=%t(g.zLogin)">Forum
       @ post timeline</a> for user <b>%h(g.zLogin)</b></p>
     }
+    @ <hr><p>
+    @ Select your preferred <a href="%R/skins">site skin</a>.
+    @ </p>
     if( g.perm.Password ){
       char *zRPW = fossil_random_password(12);
       @ <hr>
@@ -1031,7 +1017,7 @@ void login_resetpw(void){
     @ Password-reset URLs have a short lifespan.
     @ </span></p>
     style_finish_page();
-    sleep(1);  /* Introduce a small delay on an invalid suffix as an 
+    sleep(1);  /* Introduce a small delay on an invalid suffix as an
                ** extra defense against search attacks */
     return;
   }
@@ -1165,7 +1151,7 @@ static int login_transfer_credentials(
       db_multi_exec(
         "UPDATE user SET cookie=%Q, cexpire=%.17g"
         " WHERE login=%Q",
-        zHash, 
+        zHash,
         sqlite3_column_double(pStmt, 0), zLogin
       );
       db_protect_pop();
@@ -1582,7 +1568,7 @@ void login_set_capabilities(const char *zCap, unsigned flags){
                              p->TktFmt = p->Attach = p->ApndTkt =
                              p->ModWiki = p->ModTkt =
                              p->RdForum = p->WrForum = p->ModForum =
-                             p->WrTForum = p->AdminForum = p->Chat = 
+                             p->WrTForum = p->AdminForum = p->Chat =
                              p->EmailAlert = p->Announce = p->Debug = 1;
                              /* Fall thru into Read/Write */
       case 'i':   p->Read = p->Write = 1;                      break;
@@ -1829,7 +1815,7 @@ void login_insert_csrf_secret(void){
 
 /*
 ** Check to see if the candidate username zUserID is already used.
-** Return 1 if it is already in use.  Return 0 if the name is 
+** Return 1 if it is already in use.  Return 0 if the name is
 ** available for a self-registeration.
 */
 static int login_self_choosen_userid_already_exists(const char *zUserID){
@@ -1851,7 +1837,7 @@ static int login_self_choosen_userid_already_exists(const char *zUserID){
 */
 static int email_address_in_use(const char *zEMail){
   int uid;
-  uid = db_int(0, 
+  uid = db_int(0,
     "SELECT uid FROM user"
     " WHERE info LIKE '%%<%q>%%'", zEMail);
   if( uid>0 ){
@@ -1880,7 +1866,7 @@ static int email_address_in_use(const char *zEMail){
 /*
 ** COMMAND: test-email-used
 ** Usage:  fossil test-email-used EMAIL ...
-** 
+**
 ** Given a list of email addresses, show the UID and LOGIN associated
 ** with each one.
 */
@@ -1905,7 +1891,7 @@ void test_email_used(void){
     }
   }
 }
-    
+
 
 /*
 ** Check an email address and confirm that it is valid for self-registration.
@@ -1997,7 +1983,7 @@ void register_page(void){
   }else if( sqlite3_strglob("*[^-a-zA-Z0-9_.]*",zUserID)==0 ){
     iErrLine = 1;
     zErr = "User ID may not contain spaces or special characters.";
-  }else if( sqlite3_strlike("anonymous%", zUserID, 0)==0 
+  }else if( sqlite3_strlike("anonymous%", zUserID, 0)==0
          || sqlite3_strlike("nobody%", zUserID, 0)==0
          || sqlite3_strlike("reader%", zUserID, 0)==0
          || sqlite3_strlike("developer%", zUserID, 0)==0
