@@ -454,7 +454,7 @@ static void stylesheet_url_var(void){
     blob_appendf(&url, "&skin=%s&once", skin_in_use());
   }
 
-  /* Generate the CSS URL variable */  
+  /* Generate the CSS URL variable */
   Th_Store("stylesheet_url", blob_str(&url));
   blob_reset(&url);
 }
@@ -474,7 +474,7 @@ static void image_url_var(const char *zImageName){
   zResource = mprintf("%s-image", zImageName);
   zUrl = mprintf("%R/%s?id=%x", zImageName, skin_id(zResource));
   free(zResource);
-  zVarName = mprintf("%s_image_url", zImageName);  
+  zVarName = mprintf("%s_image_url", zImageName);
   Th_Store(zVarName, zUrl);
   free(zVarName);
   free(zUrl);
@@ -599,7 +599,7 @@ char *style_nonce(void){
 ** should be released by the caller.
 */
 char *style_csp(int toHeader){
-  static const char zBackupCSP[] = 
+  static const char zBackupCSP[] =
    "default-src 'self' data:; "
    "script-src 'self' 'nonce-$nonce'; "
    "style-src 'self' 'unsafe-inline'; "
@@ -635,7 +635,7 @@ char *style_csp(int toHeader){
 ** Disable content security policy for the current page.
 ** WARNING:  Do not do this lightly!
 **
-** This routine must be called before the CSP is sued by 
+** This routine must be called before the CSP is sued by
 ** style_header().
 */
 void style_disable_csp(void){
@@ -647,7 +647,7 @@ void style_disable_csp(void){
 ** header template lacks a <body> tag, then all of the following is
 ** prepended.
 */
-static const char zDfltHeader[] = 
+static const char zDfltHeader[] =
 @ <html>
 @ <head>
 @ <meta charset="UTF-8">
@@ -672,7 +672,7 @@ const char *get_default_header(){
 /*
 ** The default TCL list that defines the main menu.
 */
-static const char zDfltMainMenu[] = 
+static const char zDfltMainMenu[] =
 @ Home      /home        *              {}
 @ Timeline  /timeline    {o r j}        {}
 @ Files     /dir?ci=tip  oh             desktoponly
@@ -797,8 +797,8 @@ static void style_init_th1_vars(const char *zTitle){
   if( g.ftntsIssues[0] || g.ftntsIssues[1] ||
       g.ftntsIssues[2] || g.ftntsIssues[3] ){
     char buf[80];
-    sqlite3_snprintf(sizeof(buf),buf,"%i %i %i %i",g.ftntsIssues[0],g.ftntsIssues[1],
-                                  g.ftntsIssues[2],g.ftntsIssues[3]);
+    sqlite3_snprintf(sizeof(buf), buf, "%i %i %i %i", g.ftntsIssues[0],
+                     g.ftntsIssues[1], g.ftntsIssues[2], g.ftntsIssues[3]);
     Th_Store("footnotes_issues_counters", buf);
   }
 }
@@ -1287,7 +1287,7 @@ static void page_style_css_append_page_style(Blob *pOut){
 **    *   $background
 **
 ** The output from TH1 becomes the style sheet.  Fossil always reports
-** that the style sheet is cacheable.  
+** that the style sheet is cacheable.
 */
 void page_style_css(void){
   Blob css = empty_blob;
@@ -1327,7 +1327,7 @@ void page_style_css(void){
 /*
 ** All possible capabilities
 */
-static const char allCap[] = 
+static const char allCap[] =
   "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKL";
 
 /*
@@ -1400,7 +1400,7 @@ void honeypot_page(void){
 ** If zFormat is an empty string, then this is the /test_env page.
 */
 void webpage_error(const char *zFormat, ...){
-  int showAll;
+  int showAll = 0;
   char *zErr = 0;
   int isAuth = 0;
   char zCap[100];
@@ -1481,7 +1481,7 @@ void webpage_error(const char *zFormat, ...){
          break;
       }
     }
-    
+
     @ fossil_exe_id() = %h(fossil_exe_id())<br>
     if( g.perm.Admin ){
       int k;
@@ -1497,6 +1497,10 @@ void webpage_error(const char *zFormat, ...){
     P("HTTP_USER_AGENT");
     P("SERVER_SOFTWARE");
     cgi_print_all(showAll, 0, 0);
+    @ <p><form method="POST" action="%R/test_env">
+    @ <input type="hidden" name="showall" value="%d(showAll)">
+    @ <input type="submit" name="post-test-button" value="POST Test">
+    @ </form>
     if( showAll && blob_size(&g.httpHeader)>0 ){
       @ <hr>
       @ <pre>
@@ -1653,7 +1657,7 @@ void style_labeled_checkbox(const char * zWrapperId,
 **                       atoi(PD("my_field","0")),
 **                       "", 1, "2", 2, "Three", 3,
 **                       NULL);
-** 
+**
 */
 void style_select_list_int(const char * zWrapperId,
                            const char *zFieldName, const char * zLabel,
@@ -1777,7 +1781,7 @@ void style_script_begin(const char *zOrigin, int iLine){
   CX("<script nonce='%s'>/* %s:%d */\n", style_nonce(), zOrigin, iLine);
 }
 
-/* Generate the closing </script> tag 
+/* Generate the closing </script> tag
 */
 void style_script_end(void){
   CX("</script>\n");
