@@ -46,7 +46,7 @@ static void tag_propagate(
 
   assert( tagType==0 || tagType==2 );
   pqueuex_init(&queue);
-  pqueuex_insert(&queue, pid, 0.0, 0);
+  pqueuex_insert(&queue, pid, 0.0);
 
   /* Query for children of :pid to which to propagate the tag.
   ** Three returns:  (1) rid of the child.  (2) timestamp of child.
@@ -81,14 +81,14 @@ static void tag_propagate(
       "UPDATE event SET bgcolor=%Q WHERE objid=:rid", zValue
     );
   }
-  while( (pid = pqueuex_extract(&queue, 0))!=0 ){
+  while( (pid = pqueuex_extract(&queue))!=0 ){
     db_bind_int(&s, ":pid", pid);
     while( db_step(&s)==SQLITE_ROW ){
       int doit = db_column_int(&s, 2);
       if( doit ){
         int cid = db_column_int(&s, 0);
         double mtime = db_column_double(&s, 1);
-        pqueuex_insert(&queue, cid, mtime, 0);
+        pqueuex_insert(&queue, cid, mtime);
         db_bind_int(&ins, ":rid", cid);
         db_step(&ins);
         db_reset(&ins);
@@ -404,13 +404,13 @@ static void tag_cmd_tagname_check(const char *zTag){
 **         propagates to all descendants of that artifact.
 **
 **         Options:
-**           --raw                      Raw tag name. Ignored for
-**                                      non-CHECK-IN artifacts.
-**           --propagate                Propagating tag
 **           --date-override DATETIME   Set date and time added
-**           --user-override USER       Name USER when adding the tag
 **           -n|--dry-run               Display the tag text, but do not
 **                                      actually insert it into the database
+**           --propagate                Propagating tag
+**           --raw                      Raw tag name. Ignored for
+**                                      non-CHECK-IN artifacts.
+**           --user-override USER       Name USER when adding the tag
 **
 **         The --date-override and --user-override options support
 **         importing history from other SCM systems. DATETIME has
@@ -429,18 +429,19 @@ static void tag_cmd_tagname_check(const char *zTag){
 **         forbidden, as documented for the 'add' subcommand.
 **
 **         Options:
-**           --raw                       Raw tag name. Ignored for
-**                                       non-CHECK-IN artifacts.
 **           --date-override DATETIME    Set date and time deleted
-**           --user-override USER        Name USER when deleting the tag
 **           -n|--dry-run                Display the control artifact, but do
 **                                       not insert it into the database
+**           --raw                       Raw tag name. Ignored for
+**                                       non-CHECK-IN artifacts.
+**           --user-override USER        Name USER when deleting the tag
 **
 ** > fossil tag find ?OPTIONS? TAGNAME
 **
 **         List all objects that use TAGNAME.
 **
 **         Options:
+**           -n|--limit N    Limit to N results
 **           --raw           Interprets tag as a raw name instead of a
 **                           branch name and matches any type of artifact.
 **                           Changes the output to include only the
@@ -449,7 +450,6 @@ static void tag_cmd_tagname_check(const char *zTag){
 **                           e (event/technote), f (forum post),
 **                           t (ticket). Default is all types. Ignored
 **                           if --raw is used.
-**           -n|--limit N    Limit to N results
 **
 ** > fossil tag list|ls ?OPTIONS? ?ARTIFACT-ID?
 **
@@ -461,9 +461,6 @@ static void tag_cmd_tagname_check(const char *zTag){
 **         unless the --raw or --prefix options are used.
 **
 **         Options:
-**           --raw           List raw names of tags
-**           --tagtype TYPE  List only tags of type TYPE, which must
-**                           be one of: cancel, singleton, propagated
 **           -v|--inverse    Inverse the meaning of --tagtype TYPE
 **           --prefix        List only tags with the given prefix
 **                           Fossil-internal prefixes include "sym-"
@@ -472,6 +469,9 @@ static void tag_cmd_tagname_check(const char *zTag){
 **                           prefix is stripped from the resulting
 **                           list unless --raw is provided. Ignored if
 **                           ARTIFACT-ID is provided.
+**           --raw           List raw names of tags
+**           --tagtype TYPE  List only tags of type TYPE, which must
+**                           be one of: cancel, singleton, propagated
 **
 ** The option --raw allows the manipulation of all types of tags
 ** used for various internal purposes in fossil. It also shows
@@ -642,9 +642,9 @@ void tag_cmd(void){
       int l = strlen(zTagType);
       if( strncmp(zTagType,"cancel",l)==0 ){
         nTagType = 0;
-      }else if( strncmp(zTagType,"singleton",l)==0 ){ 
+      }else if( strncmp(zTagType,"singleton",l)==0 ){
         nTagType = 1;
-      }else if( strncmp(zTagType,"propagated",l)==0 ){ 
+      }else if( strncmp(zTagType,"propagated",l)==0 ){
         nTagType = 2;
       }else{
         fossil_fatal("unrecognized tag type");
