@@ -35,14 +35,17 @@
 /*
 ** Flags for url_parse()
 */
-#define URL_PROMPT_PW        0x001  /* Prompt for password if needed */
-#define URL_REMEMBER         0x002  /* Remember the url for later reuse */
-#define URL_ASK_REMEMBER_PW  0x004  /* Ask whether to remember prompted pw */
-#define URL_REMEMBER_PW      0x008  /* Should remember pw */
-#define URL_PROMPTED         0x010  /* Prompted for PW already */
-#define URL_OMIT_USER        0x020  /* Omit the user name from URL */
-#define URL_USE_CONFIG       0x040  /* Use remembered URLs from CONFIG table */
-#define URL_USE_PARENT       0x080  /* Use the URL of the parent project */
+#define URL_PROMPT_PW        0x0001  /* Prompt for password if needed */
+#define URL_REMEMBER         0x0002  /* Remember the url for later reuse */
+#define URL_ASK_REMEMBER_PW  0x0004  /* Ask whether to remember prompted pw */
+#define URL_REMEMBER_PW      0x0008  /* Should remember pw */
+#define URL_PROMPTED         0x0010  /* Prompted for PW already */
+#define URL_OMIT_USER        0x0020  /* Omit the user name from URL */
+#define URL_USE_CONFIG       0x0040  /* Use remembered URLs from CONFIG table */
+#define URL_USE_PARENT       0x0080  /* Use the URL of the parent project */
+#define URL_SSH_PATH         0x0100  /* Include PATH= on SSH syncs */
+#define URL_SSH_RETRY        0x0200  /* This a retry of an SSH */
+#define URL_SSH_EXE          0x0400  /* ssh: URL contains fossil= query param*/
 
 /*
 ** The URL related data used with this subsystem.
@@ -63,10 +66,12 @@ struct UrlData {
   char *canonical;      /* Canonical representation of the URL */
   char *proxyAuth;      /* Proxy-Authorizer: string */
   char *fossil;         /* The fossil query parameter on ssh: */
+  char *pwConfig;       /* CONFIG table entry that gave us the password */
   unsigned flags;       /* Boolean flags controlling URL processing */
   int useProxy;         /* Used to remember that a proxy is in use */
-  char *proxyUrlPath;
-  int proxyOrigPort;    /* Tunneled port number for https through proxy */
+  int proxyOrigPort;       /* Tunneled port number for https through proxy */
+  char *proxyUrlPath;      /* Remember path when proxy is use */
+  char *proxyUrlCanonical; /* Remember canonical path when proxy is use */
 };
 #endif /* INTERFACE */
 
@@ -88,13 +93,13 @@ struct UrlData {
 **      hostname    HOST:PORT or just HOST if port is the default.
 **      canonical   The URL in canonical form, omitting the password
 **
-** If zUrl==0 and URL_USE_CONFIG is set, then parse the URL stored
-** in last-sync-url and last-sync-pw of the CONFIG table.  Or if 
+** If URL_USECONFIG is set and zUrl is NULL or "default", then parse the
+** URL stored in last-sync-url and last-sync-pw of the CONFIG table.  Or if
 ** URL_USE_PARENT is also set, then use parent-project-url and
 ** parent-project-pw from the CONFIG table instead of last-sync-url
 ** and last-sync-pw.
 **
-** If zUrl is a symbolic name and URL_USE_CONFIG is true, then look up
+** If URL_USE_CONFIG is set and zUrl is a symbolic name, then look up
 ** the URL in sync-url:%Q and sync-pw:%Q elements of the CONFIG table where
 ** %Q is the symbolic name.
 **
@@ -110,6 +115,7 @@ void url_parse_local(
   int i, j, c;
   char *zFile = 0;
 
+  memset(pUrlData, 0, sizeof(*pUrlData));
   if( urlFlags & URL_USE_CONFIG ){
     if( zUrl==0 || strcmp(zUrl,"default")==0 ){
       const char *zPwConfig = "last-sync-pw";
@@ -126,13 +132,14 @@ void url_parse_local(
       if( zUrl==0 ) return;
       if( pUrlData->passwd==0 ){
         pUrlData->passwd = unobscure(db_get(zPwConfig, 0));
+        pUrlData->pwConfig = fossil_strdup(zPwConfig);
       }
       pUrlData->isAlias = 1;
     }else{
       char *zKey = sqlite3_mprintf("sync-url:%q", zUrl);
       char *zAlt = db_get(zKey, 0);
-      sqlite3_free(zKey);
       if( zAlt ){
+        pUrlData->pwConfig = mprintf("sync-pw:%q", zUrl);
         pUrlData->passwd = unobscure(
           db_text(0, "SELECT value FROM config WHERE name='sync-pw:%q'",zUrl)
         );
@@ -142,6 +149,7 @@ void url_parse_local(
       }else{
         pUrlData->isAlias = 0;
       }
+      sqlite3_free(zKey);
     }
   }else{
     if( zUrl==0 ) return;
@@ -156,8 +164,6 @@ void url_parse_local(
     char *zExe;
     char cQuerySep = '?';
 
-    pUrlData->isFile = 0;
-    pUrlData->useProxy = 0;
     if( zUrl[4]=='s' ){
       pUrlData->isHttps = 1;
       pUrlData->protocol = "https";
@@ -252,11 +258,13 @@ void url_parse_local(
         i++;
       }
       if( fossil_strcmp(zName,"fossil")==0 ){
+        fossil_free(pUrlData->fossil);
         pUrlData->fossil = fossil_strdup(zValue);
         dehttpize(pUrlData->fossil);
         fossil_free(zExe);
         zExe = mprintf("%cfossil=%T", cQuerySep, pUrlData->fossil);
         cQuerySep = '&';
+        urlFlags |= URL_SSH_EXE;
       }
     }
 
@@ -314,7 +322,7 @@ void url_parse_local(
     pUrlData->name = mprintf("%b", &cfile);
     pUrlData->canonical = mprintf("file://%T", pUrlData->name);
     blob_reset(&cfile);
-  }else if( pUrlData->user!=0 && pUrlData->passwd==0 
+  }else if( pUrlData->user!=0 && pUrlData->passwd==0
          && (urlFlags & URL_PROMPT_PW)!=0 ){
     url_prompt_for_password_local(pUrlData);
   }else if( pUrlData->user!=0 && ( urlFlags & URL_ASK_REMEMBER_PW ) ){
@@ -405,9 +413,19 @@ void url_unparse(UrlData *p){
   fossil_free(p->user);
   fossil_free(p->passwd);
   fossil_free(p->fossil);
+  fossil_free(p->pwConfig);
   memset(p, 0, sizeof(*p));
 }
 
+/*
+** Move a URL parse from one UrlData object to another.
+*/
+void url_move_parse(UrlData *pTo, UrlData *pFrom){
+  url_unparse(pTo);
+  memcpy(pTo, pFrom, sizeof(*pTo));
+  memset(pFrom, 0, sizeof(*pFrom));
+}
+
 /*
 ** Parse the given URL, which describes a sync server.  Populate variables
 ** in the global "g.url" structure as shown below.  If zUrl is NULL, then
@@ -426,6 +444,7 @@ void url_unparse(UrlData *p){
 **      g.url.passwd      Password.
 **      g.url.hostname    HOST:PORT or just HOST if port is the default.
 **      g.url.canonical   The URL in canonical form, omitting the password
+**      g.url.pwConfig    Name of CONFIG table entry containing the password
 **
 ** HTTP url format as follows (HTTPS is the same with a different scheme):
 **
@@ -435,48 +454,75 @@ void url_unparse(UrlData *p){
 **
 **     ssh://userid@host:port/path?fossil=path/to/fossil.exe
 **
+** If URL_USE_CONFIG is set then the URL and password might be pulled from
+** the CONFIG table rather than from the zUrl parameter.  If zUrl is NULL
+** or "default" then the URL is given by the "last-sync-url" setting and
+** the password comes form the "last-sync-pw" setting.  If zUrl is a symbolic
+** name, then the URL comes from "sync-url:NAME" and the password from
+** "sync-pw:NAME" where NAME is the input zUrl string.  Whenever the
+** password is taken from the CONFIG table, the g.url.pwConfig field is
+** set to the CONFIG.NAME value from which that password is taken.  Otherwise,
+** g.url.pwConfig is NULL.
 */
 void url_parse(const char *zUrl, unsigned int urlFlags){
   url_parse_local(zUrl, urlFlags, &g.url);
 }
 
+/*
+** Print the content of g.url
+*/
+void urlparse_print(int showPw){
+  fossil_print("g.url.isFile    = %d\n", g.url.isFile);
+  fossil_print("g.url.isHttps   = %d\n", g.url.isHttps);
+  fossil_print("g.url.isSsh     = %d\n", g.url.isSsh);
+  fossil_print("g.url.protocol  = %s\n", g.url.protocol);
+  fossil_print("g.url.name      = %s\n", g.url.name);
+  fossil_print("g.url.port      = %d\n", g.url.port);
+  fossil_print("g.url.dfltPort  = %d\n", g.url.dfltPort);
+  fossil_print("g.url.hostname  = %s\n", g.url.hostname);
+  fossil_print("g.url.path      = %s\n", g.url.path);
+  fossil_print("g.url.user      = %s\n", g.url.user);
+  if( showPw || g.url.pwConfig==0 ){
+    fossil_print("g.url.passwd    = %s\n", g.url.passwd);
+  }else{
+    fossil_print("g.url.passwd    = ************\n");
+  }
+  fossil_print("g.url.pwConfig  = %s\n", g.url.pwConfig);
+  fossil_print("g.url.canonical = %s\n", g.url.canonical);
+  fossil_print("g.url.fossil    = %s\n", g.url.fossil);
+  fossil_print("g.url.flags     = 0x%04x\n", g.url.flags);
+  fossil_print("url_full(g.url) = %z\n", url_full(&g.url));
+}
+
 /*
 ** COMMAND: test-urlparser
 **
 ** Usage: %fossil test-urlparser URL ?options?
 **
-**    --remember      Store results in last-sync-url
 **    --prompt-pw     Prompt for password if missing
+**    --remember      Store results in last-sync-url
+**    --show-pw       Show the CONFIG-derived password in the output
+**    --use-config    Pull URL and password from the CONFIG table
+**    --use-parent    Use the parent project URL
 */
 void cmd_test_urlparser(void){
   int i;
   unsigned fg = 0;
+  int showPw = 0;
+  db_must_be_within_tree();
   url_proxy_options();
-  if( find_option("remember",0,0) ){
-    db_must_be_within_tree();
-    fg |= URL_REMEMBER;
-  }
-  if( find_option("prompt-pw",0,0) ) fg |= URL_PROMPT_PW;
+  if( find_option("remember",0,0) )    fg |= URL_REMEMBER;
+  if( find_option("prompt-pw",0,0) )   fg |= URL_PROMPT_PW;
+  if( find_option("use-parent",0,0) )  fg |= URL_USE_PARENT|URL_USE_CONFIG;
+  if( find_option("use-config",0,0) )  fg |= URL_USE_CONFIG;
+  if( find_option("show-pw",0,0) )     showPw = 1;
+  if( (fg & URL_USE_CONFIG)==0 )       showPw = 1;
   if( g.argc!=3 && g.argc!=4 ){
     usage("URL");
   }
   url_parse(g.argv[2], fg);
   for(i=0; i<2; i++){
-    fossil_print("g.url.isFile    = %d\n", g.url.isFile);
-    fossil_print("g.url.isHttps   = %d\n", g.url.isHttps);
-    fossil_print("g.url.isSsh     = %d\n", g.url.isSsh);
-    fossil_print("g.url.protocol  = %s\n", g.url.protocol);
-    fossil_print("g.url.name      = %s\n", g.url.name);
-    fossil_print("g.url.port      = %d\n", g.url.port);
-    fossil_print("g.url.dfltPort  = %d\n", g.url.dfltPort);
-    fossil_print("g.url.hostname  = %s\n", g.url.hostname);
-    fossil_print("g.url.path      = %s\n", g.url.path);
-    fossil_print("g.url.user      = %s\n", g.url.user);
-    fossil_print("g.url.passwd    = %s\n", g.url.passwd);
-    fossil_print("g.url.canonical = %s\n", g.url.canonical);
-    fossil_print("g.url.fossil    = %s\n", g.url.fossil);
-    fossil_print("g.url.flags     = 0x%02x\n", g.url.flags);
-    fossil_print("url_full(g.url) = %z\n", url_full(&g.url));
+    urlparse_print(showPw);
     if( g.url.isFile || g.url.isSsh ) break;
     if( i==0 ){
       fossil_print("********\n");
@@ -535,8 +581,8 @@ void url_enable_proxy(const char *zMsg){
   const char *zProxy;
   zProxy = zProxyOpt;
   if( zProxy==0 ){
-    zProxy = db_get("proxy", 0);
-    if( zProxy==0 || zProxy[0]==0 || is_false(zProxy) ){
+    zProxy = db_get("proxy", "system");
+    if( fossil_strcmp(zProxy, "system")==0 ){
       zProxy = fossil_getenv("http_proxy");
     }
   }
@@ -566,6 +612,7 @@ void url_enable_proxy(const char *zMsg){
     g.url.passwd = zOriginalPasswd;
     g.url.isHttps = fOriginalIsHttps;
     g.url.useProxy = 1;
+    g.url.proxyUrlCanonical = zOriginalUrl;;
     g.url.proxyUrlPath = zOriginalUrlPath;
     g.url.proxyOrigPort = iOriginalPort;
     g.url.flags = uOriginalFlags;
@@ -724,10 +771,16 @@ void url_prompt_for_password(void){
 */
 void url_remember(void){
   if( g.url.flags & URL_REMEMBER ){
-    if( g.url.flags & URL_USE_PARENT ){
-      db_set("parent-project-url", g.url.canonical, 0);
+    const char *url;
+    if( g.url.useProxy ){
+      url = g.url.proxyUrlCanonical;
     }else{
-      db_set("last-sync-url", g.url.canonical, 0);
+      url = g.url.canonical;
+    }
+    if( g.url.flags & URL_USE_PARENT ){
+      db_set("parent-project-url", url, 0);
+    }else{
+      db_set("last-sync-url", url, 0);
     }
     if( g.url.user!=0 && g.url.passwd!=0 && ( g.url.flags & URL_REMEMBER_PW ) ){
       if( g.url.flags & URL_USE_PARENT ){
@@ -759,7 +812,7 @@ void url_get_password_if_needed(void){
 **       elided.
 **
 **    *  If the URL is just a domain name, without a path, then use the
-**       first element of the domain name, except skip over "www." if 
+**       first element of the domain name, except skip over "www." if
 **       present and if there is a ".com" or ".org" or similar suffix.
 **
 ** The string returned is obtained from fossil_malloc().  NULL might be
