@@ -357,7 +357,7 @@ static void xfer_accept_unversioned_file(Xfer *pXfer, int isWriter){
 
   /* The isWriter flag must be true in order to land the new file */
   if( !isWriter ){
-    blob_appendf(&pXfer->err, "Write permissions for unversioned files missing");
+    blob_appendf(&pXfer->err,"Write permissions for unversioned files missing");
     goto end_accept_unversioned_file;
   }
 
@@ -1191,7 +1191,7 @@ static int disableLogin = 0;
 ** clone clients to specify a URL that omits default pathnames, such
 ** as "http://fossil-scm.org/" instead of "http://fossil-scm.org/index.cgi".
 **
-** WEBPAGE: xfer  raw-content
+** WEBPAGE: xfer  raw-content  loadavg-exempt
 **
 ** This is the transfer handler on the server side.  The transfer
 ** message has been uncompressed and placed in the g.cgiIn blob.
@@ -1586,7 +1586,7 @@ void page_xfer(void){
 
     /*    pragma NAME VALUE...
     **
-    ** The client issue pragmas to try to influence the behavior of the
+    ** The client issues pragmas to try to influence the behavior of the
     ** server.  These are requests only.  Unknown pragmas are silently
     ** ignored.
     */
@@ -1836,7 +1836,7 @@ void page_xfer(void){
       if( x.name!=0 && sqlite3_strlike("%localhost%", x.name, 0)!=0 ){
         @ pragma link %F(x.canonical) %F(zArg) %lld(iMtime)
       }
-      url_unparse(&x);      
+      url_unparse(&x);
     }
     db_finalize(&q);
   }
@@ -1861,7 +1861,7 @@ void page_xfer(void){
 ** protocol handler.  Generate a reply on standard output.
 **
 ** This command was original created to help debug the server side of
-** sync messages.  The XFERFILE is the uncompressed content of an 
+** sync messages.  The XFERFILE is the uncompressed content of an
 ** "xfer" HTTP request from client to server.  This command interprets
 ** that message and generates the content of an HTTP reply (without any
 ** encoding and without the HTTP reply headers) and writes that reply
@@ -1929,6 +1929,7 @@ static const char zBriefFormat[] =
 #define SYNC_NOHTTPCOMPRESS 0x04000    /* Do not compression HTTP messages */
 #define SYNC_ALLURL         0x08000    /* The --all flag - sync to all URLs */
 #define SYNC_SHARE_LINKS    0x10000    /* Request alternate repo links */
+#define SYNC_XVERBOSE       0x20000    /* Extra verbose.  Network traffic */
 #endif
 
 /*
@@ -1950,7 +1951,8 @@ int client_sync(
   unsigned syncFlags,      /* Mask of SYNC_* flags */
   unsigned configRcvMask,  /* Receive these configuration items */
   unsigned configSendMask, /* Send these configuration items */
-  const char *zAltPCode    /* Alternative project code (usually NULL) */
+  const char *zAltPCode,   /* Alternative project code (usually NULL) */
+  int *pnRcvd              /* Set to # received artifacts, if not NULL */
 ){
   int go = 1;             /* Loop until zero */
   int nCardSent = 0;      /* Number of cards sent */
@@ -1990,6 +1992,7 @@ int client_sync(
   const char *zClientId;  /* A unique identifier for this check-out */
   unsigned int mHttpFlags;/* Flags for the http_exchange() subsystem */
 
+  if( pnRcvd ) *pnRcvd = 0;
   if( db_get_boolean("dont-push", 0) ) syncFlags &= ~SYNC_PUSH;
   if( (syncFlags & (SYNC_PUSH|SYNC_PULL|SYNC_CLONE|SYNC_UNVERSIONED))==0
      && configRcvMask==0
@@ -2262,7 +2265,9 @@ int client_sync(
     blob_appendf(&send, "# %s\n", zRandomness);
     free(zRandomness);
 
-    if( syncFlags & SYNC_VERBOSE ){
+    if( (syncFlags & SYNC_VERBOSE)!=0
+     && (syncFlags & SYNC_XVERBOSE)==0
+    ){
       fossil_print("waiting for server...");
     }
     fflush(stdout);
@@ -2276,6 +2281,9 @@ int client_sync(
     if( syncFlags & SYNC_NOHTTPCOMPRESS ){
       mHttpFlags |= HTTP_NOCOMPRESS;
     }
+    if( syncFlags & SYNC_XVERBOSE ){
+      mHttpFlags |= HTTP_VERBOSE;
+    }
 
     /* Do the round-trip to the server */
     if( http_exchange(&send, &recv, mHttpFlags, MAX_REDIRECTS, 0) ){
@@ -2524,7 +2532,7 @@ int client_sync(
             "         sufficient permission on the server\n"
           );
           uvPullOnly = 2;
-        }          
+        }
         if( iStatus<=3 || uvPullOnly ){
           db_multi_exec("DELETE FROM uv_tosend WHERE name=%Q", zName);
         }else if( iStatus==4 ){
@@ -2641,7 +2649,7 @@ int client_sync(
       if( blob_eq(&xfer.aToken[0], "pragma") && xfer.nToken>=2 ){
         /*   pragma server-version VERSION ?DATE? ?TIME?
         **
-        ** The servger announces to the server what version of Fossil it
+        ** The server announces to the server what version of Fossil it
         ** is running.  The DATE and TIME are a pure numeric ISO8601 time
         ** for the specific check-in of the client.
         */
@@ -2656,7 +2664,7 @@ int client_sync(
         /*   pragma uv-pull-only
         **   pragma uv-push-ok
         **
-        ** If the server is unwill to accept new unversioned content (because
+        ** If the server is unwilling to accept new unversioned content (because
         ** this client lacks the necessary permissions) then it sends a
         ** "uv-pull-only" pragma so that the client will know not to waste
         ** bandwidth trying to upload unversioned content.  If the server
@@ -2848,6 +2856,7 @@ int client_sync(
     db_end_transaction(0);
   };
   transport_stats(&nSent, &nRcvd, 1);
+  if( pnRcvd ) *pnRcvd = nArtifactRcvd;
   if( (rSkew*24.0*3600.0) > 10.0 ){
      fossil_warning("*** time skew *** server is fast by %s",
                     db_timespan_name(rSkew));
@@ -2878,6 +2887,8 @@ int client_sync(
     fossil_print(
       "Uncompressed payload sent: %lld  received: %lld\n", nUncSent, nUncRcvd);
   }
+  blob_reset(&send);
+  blob_reset(&recv);
   transport_close(&g.url);
   transport_global_shutdown(&g.url);
   if( nErr && go==2 ){
