@@ -168,8 +168,8 @@ puts $out {
 <li> <a href='../COPYRIGHT-BSD2.txt'>License</a>
 <li> <a href='userlinks.wiki'>Miscellaneous Docs for Fossil Users</a>
 <li> <a href='hacker-howto.wiki'>Fossil Developer's Guide</a>
-  <ul><li><a href='$ROOT/wiki?name=Release Build How-To'>Release Build How-To</a>, a.k.a.
-  how deliverables are built</li></ul>
+<li><a href='$ROOT/wiki?name=Release Build How-To'>Release Build How-To</a>,
+a.k.a.  how deliverables are built</li>
 </li>
 <li> <a href='$ROOT/wiki?name=To+Do+List'>To Do List (Wiki)</a>
 <li> <a href='https://fossil-scm.org/fossil-book/'>Fossil book</a>
